@@ -19,8 +19,11 @@
 
 #include "attributefactory.h"
 
+#include "collectionquotaattribute.h"
 #include "collectionrightsattribute_p.h"
 #include "entitydisplayattribute.h"
+#include "entityhiddenattribute.h"
+#include "persistentsearchattribute.h"
 
 #include <KGlobal>
 
@@ -28,6 +31,9 @@
 
 using namespace Akonadi;
 
+namespace Akonadi {
+namespace Internal {
+
 /**
  * @internal
  */
@@ -52,15 +58,6 @@ class DefaultAttribute : public Attribute
     QByteArray mType, mValue;
 };
 
-/**
- * @internal
- */
-class AttributeFactory::Private
-{
-  public:
-    QHash<QByteArray, Attribute*> attributes;
-};
-
 /**
  * @internal
  */
@@ -74,14 +71,30 @@ class StaticAttributeFactory : public AttributeFactory
       initialized = true;
 
       // Register built-in attributes
+      AttributeFactory::registerAttribute<CollectionQuotaAttribute>();
       AttributeFactory::registerAttribute<CollectionRightsAttribute>();
       AttributeFactory::registerAttribute<EntityDisplayAttribute>();
+      AttributeFactory::registerAttribute<EntityHiddenAttribute>();
+      AttributeFactory::registerAttribute<PersistentSearchAttribute>();
     }
     bool initialized;
 };
 
 K_GLOBAL_STATIC( StaticAttributeFactory, s_attributeInstance )
 
+}
+
+using Akonadi::Internal::s_attributeInstance;
+
+/**
+ * @internal
+ */
+class AttributeFactory::Private
+{
+  public:
+    QHash<QByteArray, Attribute*> attributes;
+};
+
 
 AttributeFactory* AttributeFactory::self()
 {
@@ -102,7 +115,12 @@ AttributeFactory::~ AttributeFactory()
 
 void AttributeFactory::registerAttribute(Attribute *attr)
 {
-  Q_ASSERT( !d->attributes.contains( attr->type() ) );
+  Q_ASSERT( attr );
+  QHash<QByteArray, Attribute*>::Iterator it = d->attributes.find( attr->type() );
+  if ( it != d->attributes.end() ) {
+    delete *it;
+    d->attributes.erase( it );
+  }
   d->attributes.insert( attr->type(), attr );
 }
 
@@ -111,5 +129,8 @@ Attribute* AttributeFactory::createAttribute(const QByteArray &type)
   Attribute* attr = self()->d->attributes.value( type );
   if ( attr )
     return attr->clone();
-  return new DefaultAttribute( type );
+  return new Internal::DefaultAttribute( type );
 }
+
+}
+
