@@ -21,16 +21,46 @@
 #include "itemserializerplugin.h"
 #include "item.h"
 
+#include <QtCore/QBuffer>
+
 using namespace Akonadi;
 
 ItemSerializerPlugin::~ItemSerializerPlugin()
 {
 }
 
-QSet<QByteArray> ItemSerializerPlugin::parts(const Item & item) const
+QSet<QByteArray> ItemSerializerPlugin::parts( const Item & item ) const
 {
   QSet<QByteArray> set;
   if ( item.hasPayload() )
     set.insert( Item::FullPayload );
+
   return set;
 }
+
+ItemSerializerPluginV2::~ItemSerializerPluginV2()
+{
+}
+
+QSet<QByteArray> ItemSerializerPluginV2::availableParts( const Item & item ) const
+{
+  if ( item.hasPayload() )
+    return QSet<QByteArray>();
+
+  return QSet<QByteArray>() << Item::FullPayload;
+}
+
+void ItemSerializerPluginV2::apply( Item &item, const Item &other )
+{
+  QBuffer buffer;
+  QByteArray data( other.payloadData() );
+  buffer.setBuffer( &data );
+  buffer.open( QIODevice::ReadOnly );
+
+  foreach ( const QByteArray &part, other.loadedPayloadParts() ) {
+    buffer.seek( 0 );
+    deserialize( item, part, buffer, 0 );
+  }
+
+  buffer.close();
+}
