@@ -531,7 +531,7 @@ QString KPIMUtils::emailParseResultToString( EmailParseResult errorCode )
                  "change your address." );
   case TooFewAts :
     return i18n( "The email address you entered is not valid because it "
-                 "does not contain a @."
+                 "does not contain a @. "
                  "You will not create valid messages if you do not "
                  "change your address." );
   case AddressEmpty :
@@ -590,6 +590,13 @@ bool KPIMUtils::isValidSimpleAddress( const QString &aStr )
   int atChar = aStr.lastIndexOf( '@' );
   QString domainPart = aStr.mid( atChar + 1 );
   QString localPart = aStr.left( atChar );
+
+  // Both of these parts must be non empty
+  // after all we cannot have emails like:
+  // @kde.org, or  foo@
+  if( localPart.isEmpty() || domainPart.isEmpty() )
+    return false;
+
   bool tooManyAtsFlag = false;
   bool inQuotedString = false;
   int atCount = localPart.count( '@' );
@@ -761,7 +768,7 @@ bool KPIMUtils::extractEmailAddressAndName( const QString &aStr,
       } else if ( bInQuotesOutsideOfEmail ) {
         if ( cQuotes == c ) {
           bInQuotesOutsideOfEmail = false;
-        } else {
+        } else if ( c != '\\' ) {
           name.prepend( c );
         }
       } else {
@@ -834,7 +841,7 @@ bool KPIMUtils::extractEmailAddressAndName( const QString &aStr,
       } else if ( bInQuotesOutsideOfEmail ) {
         if ( cQuotes == c ) {
           bInQuotesOutsideOfEmail = false;
-        } else {
+        } else if ( c != '\\' ) {
           name.append( c );
         }
       } else {
@@ -1063,3 +1070,18 @@ QString KPIMUtils::quoteNameIfNecessary( const QString &str )
 
   return quoted;
 }
+
+KUrl KPIMUtils::encodeMailtoUrl( const QString &mailbox )
+{
+  const QByteArray encodedPath = KMime::encodeRFC2047String( mailbox, "utf-8" );
+  KUrl mailtoUrl;
+  mailtoUrl.setProtocol( "mailto" );
+  mailtoUrl.setPath( encodedPath );
+  return mailtoUrl;
+}
+
+QString KPIMUtils::decodeMailtoUrl( const KUrl &mailtoUrl )
+{
+  Q_ASSERT( mailtoUrl.protocol().toLower() == "mailto" );
+  return KMime::decodeRFC2047String( mailtoUrl.path().toUtf8() );
+}
