@@ -144,12 +144,11 @@ ConfigPage::ConfigPage( QWidget *parent )
   setWindowTitle( i18n( "Resource Configuration" ) );
 
   QVBoxLayout *mainLayout = new QVBoxLayout( this );
+  mainLayout->setMargin( 0 );
 
   QGroupBox *groupBox = new QGroupBox( i18n( "Resources" ), this );
   QGridLayout *groupBoxLayout = new QGridLayout();
   groupBox->setLayout( groupBoxLayout );
-  groupBoxLayout->setSpacing( 6 );
-  groupBoxLayout->setMargin( 11 );
 
   d->mFamilyCombo = new KComboBox( false, groupBox );
   groupBoxLayout->addWidget( d->mFamilyCombo, 0, 0, 1, 2 );
@@ -256,8 +255,8 @@ void ConfigPage::load()
   }
 
   // Rest of the kde-3.3 compat code
-  QStringList::ConstIterator cfit = compatFamilyNames.begin();
-  for ( ; cfit != compatFamilyNames.end(); ++cfit ) {
+  QStringList::ConstIterator cfit = compatFamilyNames.constBegin();
+  for ( ; cfit != compatFamilyNames.constEnd(); ++cfit ) {
     d->mFamilyMap.append( *cfit );
     familyDisplayNames.append( *cfit );
     d->loadManager( *cfit, this );
@@ -381,7 +380,7 @@ void ConfigPage::slotAdd()
 
   ConfigDialog dlg( this, d->mFamily, resource );
 
-  if ( dlg.exec() ) {
+  if ( dlg.exec() ) { //krazy:exclude=crashy
     d->mCurrentManager->add( resource );
 
     ConfigViewItem *item = new ConfigViewItem( d->mListView, resource );
@@ -459,7 +458,7 @@ void ConfigPage::slotEdit()
 
   ConfigDialog dlg( this, d->mFamily, resource );
 
-  if ( dlg.exec() ) {
+  if ( dlg.exec() ) { //krazy:exclude=crashy
     configItem->setText( 0, resource->resourceName() );
     configItem->setText( 1, resource->type() );
 
