@@ -40,7 +40,6 @@
 #include <kpimutils/email.h>
 #include <kabc/phonenumber.h>
 #include <kabc/vcardconverter.h>
-#include <kabc/stdaddressbook.h>
 #include <kcal/incidenceformatter.h>
 #include <kcal/calendar.h>
 #include <kcal/calendarlocal.h>
@@ -479,7 +478,9 @@ QString KTnef::msTNEFToVPart( const QByteArray &tnef )
 
         // problem: the 'other' address was stored by KOrganizer in
         //          a line looking like the following one:
-        // vPart += "\nADR;TYPE=dom;TYPE=intl;TYPE=parcel;TYPE=postal;TYPE=work;TYPE=home:other_pobox;;other_str1\nother_str2;other_loc;other_region;other_pocode;other_country
+        // vPart += "\nADR;TYPE=dom;TYPE=intl;TYPE=parcel;TYPE=postal;TYPE=work;"
+        //          "TYPE=home:other_pobox;;other_str1\nother_str2;other_loc;other_region;"
+        //          "other_pocode;other_country"
 
         QString nr;
         nr = stringProp( tnefMsg, MAPI_TAG_PR_HOME_TELEPHONE_NUMBER );
