@@ -21,10 +21,13 @@
 #define MAILTRANSPORT_TRANSPORTMANAGER_H
 
 #include <mailtransport/mailtransport_export.h>
+#include <mailtransport/transporttype.h>
 
 #include <QtCore/QList>
 #include <QtCore/QObject>
 
+#include <akonadi/agenttype.h>
+
 class KJob;
 
 namespace KWallet {
@@ -34,11 +37,20 @@ namespace KWallet {
 namespace MailTransport {
 
 class Transport;
+class TransportConfigWidget;
 class TransportJob;
+class TransportManagerPrivate;
 
 /**
-  Takes care of loading and storing mail transport settings and
-  creating of transport jobs.
+  @short Central transport management interface.
+
+  This class manages the creation, configuration, and removal of mail
+  transports, as well as the loading and storing of mail transport settings.
+
+  It also handles the creation of transport jobs, although that behaviour is
+  deprecated and you are encouraged to use MessageQueueJob.
+
+  @see MessageQueueJob.
 */
 class MAILTRANSPORT_EXPORT TransportManager : public QObject
 {
@@ -46,10 +58,9 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
   Q_CLASSINFO( "D-Bus Interface", "org.kde.pim.TransportManager" )
 
   friend class Transport;
-  friend class Private;
+  friend class TransportManagerPrivate;
 
   public:
-    class Private;
 
     /**
       Destructor.
@@ -96,6 +107,11 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
     */
     QList<Transport *>transports() const;
 
+    /**
+      Returns a list of all available transport types.
+    */
+    TransportType::List types() const;
+
     /**
       Creates a new, empty Transport object. The object is owned by the caller.
       If you want to add the Transport permanently (eg. after configuring it)
@@ -114,24 +130,33 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
       Creates a mail transport job for the given transport identifier.
       Returns 0 if the specified transport is invalid.
       @param transportId The transport identifier.
+
+      @deprecated use MessageQueueJob to queue messages
+                  and rely on the Dispatcher Agent to send them.
     */
-    TransportJob *createTransportJob( int transportId );
+    MAILTRANSPORT_DEPRECATED TransportJob *createTransportJob( int transportId );
 
     /**
       Creates a mail transport job for the given transport identifer,
       or transport name.
       Returns 0 if the specified transport is invalid.
       @param transport A string defining a mail transport.
+
+      @deprecated use MessageQueueJob to queue messages
+                  and rely on the Dispatcher Agent to send them.
     */
-    TransportJob *createTransportJob( const QString &transport );
+    MAILTRANSPORT_DEPRECATED TransportJob *createTransportJob( const QString &transport );
 
     /**
       Executes the given transport job. This is the preferred way to start
       transport jobs. It takes care of asynchronously loading passwords from
       KWallet if necessary.
       @param job The completely configured transport job to execute.
+
+      @deprecated use MessageQueueJob to queue messages
+                  and rely on the Dispatcher Agent to send them.
     */
-    void schedule( TransportJob *job );
+    MAILTRANSPORT_DEPRECATED void schedule( TransportJob *job );
 
     /**
       Tries to create a transport based on KEMailSettings.
@@ -139,6 +164,33 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
     */
     void createDefaultTransport();
 
+    /// Describes when to show the transport creation dialog
+    enum ShowCondition {
+      Always,              ///< Show the transport creation dialog unconditionally
+      IfNoTransportExists  ///< Only show the transport creation dialog if no transport currently
+                           ///  exists. Ask the user if he wants to add a transport in
+                           ///  the other case.
+    };
+
+    /**
+      Shows a dialog for creating and configuring a new transport.
+      @param parent Parent widget of the dialog.
+      @param showCondition the condition under which the dialog is shown at all
+      @return True if a new transport has been created and configured.
+      @since 4.4
+    */
+    bool showTransportCreationDialog( QWidget *parent, ShowCondition showCondition = Always );
+
+    /**
+      Open a configuration dialog for an existing transport.
+      @param transport The transport to configure.  It can be a new transport,
+                       or one already managed by TransportManager.
+      @param parent The parent widget for the dialog.
+      @return True if the user clicked Ok, false if the user cancelled.
+      @since 4.4
+    */
+    bool configureTransport( Transport *transport, QWidget *parent );
+
   public Q_SLOTS:
     /**
       Returns true if there are no mail transports at all.
@@ -226,29 +278,29 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
     */
     void loadPasswords();
 
+    /**
+      Singleton class, the only instance resides in the static object sSelf.
+    */
     TransportManager();
 
   private:
-    void readConfig();
-    void writeConfig();
-    void emitChangesCommitted();
-    int createId() const;
-    void prepareWallet();
-    void validateDefault();
-    void migrateToWallet();
 
-  private Q_SLOTS:
-    void slotTransportsChanged();
-    void slotWalletOpened( bool success );
-    void dbusServiceOwnerChanged( const QString &service,
-                                  const QString &oldOwner,
-                                  const QString &newOwner );
-    void jobResult( KJob *job );
+    // These are used by our friend, Transport
+    void emitChangesCommitted();
 
   private:
-    Private *const d;
+    TransportManagerPrivate *const d;
+
+    Q_PRIVATE_SLOT( d, void slotTransportsChanged() )
+    Q_PRIVATE_SLOT( d, void slotWalletOpened( bool success ) )
+    Q_PRIVATE_SLOT( d, void dbusServiceOwnerChanged( const QString &service,
+                                                     const QString &oldOwner,
+                                                     const QString &newOwner ) )
+    Q_PRIVATE_SLOT( d, void agentTypeAdded( const Akonadi::AgentType &atype ) )
+    Q_PRIVATE_SLOT( d, void agentTypeRemoved( const Akonadi::AgentType &atype ) )
+    Q_PRIVATE_SLOT( d, void jobResult( KJob *job ) )
 };
 
-}
+} // namespace MailTransport
 
-#endif
+#endif // MAILTRANSPORT_TRANSPORTMANAGER_H
